.. :changelog:

History
-------

1.0.2 (2022-01-07)
++++++++++++++++++

* Improve performance for file selection in MessageModelList via 'prefetch_related'
* Split consumers.py into separate files for better readability & add strong typing
* Fix typo for ErrorOccured
* Fix readme

1.0.1 (2021-12-23)
++++++++++++++++++

* Remove unneeded files from release


1.0.0 (2021-12-23)
++++++++++++++++++

* Support django 4.0
* Switch to GithubCI instead of travis
* Seems good enough to make it 1.0.0


0.1.4 (2021-04-01)
++++++++++++++++++

* File upload functionality

0.1.3 (2021-03-29)
++++++++++++++++++

* Fix migrations

0.1.2 (2021-03-23)
++++++++++++++++++

* Fix errors found with tests №2

0.1.1 (2021-03-23)
++++++++++++++++++

* Fix errors found with tests


0.1.0 (2021-03-21)
++++++++++++++++++

* First release on PyPI.
